generator

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateGoFile

func GenerateGoFile(gen *protogen.Plugin, file *protogen.File, commonNamespace string)

GenerateGoFile generates Go code for the given protobuf file

func GenerateJavaFile

func GenerateJavaFile(gen *protogen.Plugin, file *protogen.File, commonNamespace string)

GenerateJavaFile generates Java code for the given protobuf file

func GeneratePythonFile

func GeneratePythonFile(gen *protogen.Plugin, file *protogen.File, commonNamespace string)

GeneratePythonFile generates Python code for the given protobuf file

Types

type PuregenDirective added in v1.1.0

type PuregenDirective struct {
	EnumType string `json:"enumType,omitempty"`
	Value    string `json:"value,omitempty"`
}

PuregenDirective represents a parsed puregen directive from comments

Jump to