Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateGoFile ¶
GenerateGoFile generates Go code for the given protobuf file
func GenerateJavaFile ¶
GenerateJavaFile generates Java code for the given protobuf file
Types ¶
type PuregenDirective ¶ added in v1.1.0
type PuregenDirective struct {
EnumType string `json:"enumType,omitempty"`
Value string `json:"value,omitempty"`
}
PuregenDirective represents a parsed puregen directive from comments
Click to show internal directories.
Click to hide internal directories.